@@ -8,19 +8,26 @@ use Crypt::OpenSSL::RSA();
 use Digest();
 use MIME::Base64();
 use Exporter();
+use Carp();
 *import = \&Exporter::import;
 our @EXPORT_OK = qw(
   pin_sha256
 );
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub pin_sha256 {
     my ($path) = @_;
-    my $x509   = Crypt::OpenSSL::X509->new_from_file($path);
-    my $pubkey = Crypt::OpenSSL::RSA->new_public_key( $x509->pubkey() );
-    my $string = $pubkey->get_public_key_x509_string();
+    my $x509 = Crypt::OpenSSL::X509->new_from_file($path);
+    my $string;
+    if ( $x509->key_alg_name() eq 'rsaEncryption' ) {
+        my $pubkey = Crypt::OpenSSL::RSA->new_public_key( $x509->pubkey() );
+        $string = $pubkey->get_public_key_x509_string();
+    }
+    else {
+        $string = $x509->pubkey();
+    }
     $string =~ s/^[-]+BEGIN[^\n]+\n//smx;
     $string =~ s/^[-]+END[^\n]+\n//smx;
     my $der    = MIME::Base64::decode($string);
@@ -40,7 +47,7 @@ HTTP::PublicKeyPins - Generate RFC 7469 HTTP Public Key Pin (HPKP) header values
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -53,9 +60,9 @@ Make it more difficult for the bad guys to Man-In-The-Middle your users TLS sess
     my $h = HTTP::Headers->new();
     $h->header( 'Public-Key-Pins-Report-Only',
             'pin-sha256="'
-          . pin_sha256('/etc/pki/tls/certs/example.crt')
+          . pin_sha256('/etc/pki/tls/certs/example.pem')
           . '"; pin-sha256="'
-          . pin_sha256('/etc/pki/tls/certs/backup.crt')
+          . pin_sha256('/etc/pki/tls/certs/backup.pem')
           . '"; report-uri="https://example.com/pkp-report.pl' );
 
     ...
@@ -96,7 +103,11 @@ HTTP::PublicKeyPins requires the following non-core modules
  
 =head1 INCOMPATIBILITIES
  
-Only handles RSA public keys at the moment. Patches welcome
+None known.
+
+=head1 SEE ALSO
+
+ L<http://tools.ietf.org/html/rfc7469>
 
 =head1 AUTHOR
 
@@ -139,9 +150,6 @@ L<http://search.cpan.org/dist/HTTP-PublicKeyPins/>
 =back
 
 
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 David Dick.
